# Copyright (c) 2014 Dave Love, Liverpool University
# The licence for this file is as for the package itself.

# Fixme: Use MPI version of fftw if/when that gets packaged.  Without it,
# presumably the FFT results are poor and only useful for relative vslues.

%bcond_with mpich

Name:           hpcc
Version:        1.4.3
Release:        1%{?dist}
Summary:        A high performance computing benchmark tool
License:        BSD
Url:            http://icl.cs.utk.edu/hpcc/index.html
Source0:        http://icl.cs.utk.edu/projectsfiles/hpcc/download/%{name}-%{version}.tar.gz

BuildRequires:  gcc-gfortran openblas-devel openmpi-devel
Requires:       openmpi

%global desc \
The HPC Challenge benchmark consists of basically 7 tests:\
\
 * HPL - the Linpack TPP benchmark which measures the floating point rate\
   of execution for solving a linear system of equations.\
 * DGEMM - measures the floating point rate of execution of double\
   precision real matrix-matrix multiplication.\
 * STREAM - a simple synthetic benchmark program that measures sustainable\
   memory bandwidth (in GB/s) and the corresponding computation rate for\
   simple vector kernel.\
 * PTRANS (parallel matrix transpose) - exercises the communications where\
   pairs of processors communicate with each other simultaneously. It is a\
   useful test of the total communications capacity of the network.\
 * RandomAccess - measures the rate of integer random updates of memory\
   (GUPS).\
 * FFT - measures the floating point rate of execution of double precision\
   complex one-dimensional Discrete Fourier Transform (DFT).\
 * Communication bandwidth and latency - a set of tests to measure latency\
   and bandwidth of a number of simultaneous communication patterns; based\
   on b_eff (effective bandwidth benchmark). 

%description
%desc

%package openmpi
Summary:        A high performance computing benchmark tool - openmpi
Requires:       openmpi

%description openmpi
%desc

This is the openmpi version.

%if %{with mpich}
%package mpich
Summary:        A high performance computing benchmark tool - mpich
BuildRequires:  mpich-devel
Requires:       mpich

%description mpich
%desc

This is the mpich version.

%endif

%prep
%setup -q
cp hpl/setup/Make.Linux_PII_FBLAS_gm hpl/Make.fedora
cp _hpccinf.txt hpccinf.txt

%build
%global dobuild \
make arch=fedora LAlib=-lopenblas HPL_OPTS=-g \
mv hpcc hpcc$MPI_SUFFIX \
make arch=fedora clean

%_openmpi_load
%dobuild
%_openmpi_unload

%if %{with mpich}
%_mpich_load
%dobuild
%_mpich_unload
%endif


%install
%global doinst mkdir -p %{buildroot}$MPI_BIN; \
  install -m755 hpcc$MPI_SUFFIX %{buildroot}$MPI_BIN

%_openmpi_load
%doinst
%_openmpi_unload

%if %{with mpich}
%_mpich_load
%doinst
%_mpich_unload
%endif

%files openmpi
%defattr(-,root,root)
%doc README.txt hpccinf.txt
%{_libdir}/openmpi/bin/*

%if %{with mpich}
%files mpich
%defattr(-,root,root)
%doc README.txt hpccinf.txt
%{_libdir}/mpich/bin/*
%endif

%changelog
* Sat Nov 29 2014 Dave Love <d.love@liverpool.ac.uk> - 1.4.3-1
- Initial version
